summaryrefslogtreecommitdiff
path: root/nuttx/configs/lm3s6965-ek
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-03-08 13:29:09 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-03-08 13:29:09 -0600
commit3100722cdd78ff94412a760138e2fd4fdc319548 (patch)
tree40fef8e42b9d2ad55872feb5a32ee6cbf9390a0c /nuttx/configs/lm3s6965-ek
parent39d69550a195f226b1985ebc62f760d286cd68c8 (diff)
downloadpx4-nuttx-3100722cdd78ff94412a760138e2fd4fdc319548.tar.gz
px4-nuttx-3100722cdd78ff94412a760138e2fd4fdc319548.tar.bz2
px4-nuttx-3100722cdd78ff94412a760138e2fd4fdc319548.zip
All files and functions beginning with lm_ changed to tiva_
Diffstat (limited to 'nuttx/configs/lm3s6965-ek')
-rw-r--r--nuttx/configs/lm3s6965-ek/README.txt4
-rw-r--r--nuttx/configs/lm3s6965-ek/include/board.h8
-rw-r--r--nuttx/configs/lm3s6965-ek/src/lm3s6965ek_internal.h4
-rw-r--r--nuttx/configs/lm3s6965-ek/src/up_boot.c4
-rw-r--r--nuttx/configs/lm3s6965-ek/src/up_ethernet.c4
-rw-r--r--nuttx/configs/lm3s6965-ek/src/up_leds.c22
-rw-r--r--nuttx/configs/lm3s6965-ek/src/up_oled.c17
-rw-r--r--nuttx/configs/lm3s6965-ek/src/up_ssi.c26
8 files changed, 45 insertions, 44 deletions
diff --git a/nuttx/configs/lm3s6965-ek/README.txt b/nuttx/configs/lm3s6965-ek/README.txt
index 11ffbc8c3..0dbeda7bd 100644
--- a/nuttx/configs/lm3s6965-ek/README.txt
+++ b/nuttx/configs/lm3s6965-ek/README.txt
@@ -283,7 +283,7 @@ IDEs
on the command line.
Startup files will probably cause you some headaches. The NuttX startup file
- is arch/arm/src/lm/lm_vectors.S.
+ is arch/arm/src/tiva/tiva_vectors.S.
NuttX EABI "buildroot" Toolchain
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -532,7 +532,7 @@ Stellaris LM3S6965 Evaluation Kit Configuration Options
to build the Stellaris Ethernet driver
CONFIG_LM_ETHLEDS - Enable to use Ethernet LEDs on the board.
CONFIG_LM_BOARDMAC - If the board-specific logic can provide
- a MAC address (via lm_ethernetmac()), then this should be selected.
+ a MAC address (via tiva_ethernetmac()), then this should be selected.
CONFIG_LM_ETHHDUPLEX - Set to force half duplex operation
CONFIG_LM_ETHNOAUTOCRC - Set to suppress auto-CRC generation
CONFIG_LM_ETHNOPAD - Set to suppress Tx padding
diff --git a/nuttx/configs/lm3s6965-ek/include/board.h b/nuttx/configs/lm3s6965-ek/include/board.h
index 112c40b7a..ce88604bc 100644
--- a/nuttx/configs/lm3s6965-ek/include/board.h
+++ b/nuttx/configs/lm3s6965-ek/include/board.h
@@ -112,7 +112,7 @@
#ifndef __ASSEMBLY__
/************************************************************************************
- * Name: lm_boardinitialize
+ * Name: tiva_boardinitialize
*
* Description:
* All Stellaris architectures must provide the following entry point. This entry
@@ -121,10 +121,10 @@
*
************************************************************************************/
-extern void lm_boardinitialize(void);
+void tiva_boardinitialize(void);
/************************************************************************************
- * Name: lm_ethernetmac
+ * Name: tiva_ethernetmac
*
* Description:
* For the Ethernet Eval Kits, the MAC address will be stored in the non-volatile
@@ -135,7 +135,7 @@ extern void lm_boardinitialize(void);
#ifdef CONFIG_LM_BOARDMAC
struct ether_addr;
-extern void lm_ethernetmac(struct ether_addr *ethaddr);
+void tiva_ethernetmac(struct ether_addr *ethaddr);
#endif
#endif /* __ASSEMBLY__ */
diff --git a/nuttx/configs/lm3s6965-ek/src/lm3s6965ek_internal.h b/nuttx/configs/lm3s6965-ek/src/lm3s6965ek_internal.h
index 00d55ed40..4b834238e 100644
--- a/nuttx/configs/lm3s6965-ek/src/lm3s6965ek_internal.h
+++ b/nuttx/configs/lm3s6965-ek/src/lm3s6965ek_internal.h
@@ -45,7 +45,7 @@
#include <nuttx/compiler.h>
#include "chip.h"
-#include "lm_gpio.h"
+#include "tiva_gpio.h"
/************************************************************************************
* Definitions
@@ -130,7 +130,7 @@
*
************************************************************************************/
-extern void weak_function lm_ssiinitialize(void);
+void weak_function lm_ssiinitialize(void);
#endif /* __ASSEMBLY__ */
#endif /* __CONFIGS_LM3S6965_EK_SRC_LM3S6965EK_INTERNAL_H */
diff --git a/nuttx/configs/lm3s6965-ek/src/up_boot.c b/nuttx/configs/lm3s6965-ek/src/up_boot.c
index 3efd2434d..fd9333e2b 100644
--- a/nuttx/configs/lm3s6965-ek/src/up_boot.c
+++ b/nuttx/configs/lm3s6965-ek/src/up_boot.c
@@ -61,7 +61,7 @@
************************************************************************************/
/************************************************************************************
- * Name: lm_boardinitialize
+ * Name: tiva_boardinitialize
*
* Description:
* All Stellaris architectures must provide the following entry point. This entry
@@ -70,7 +70,7 @@
*
************************************************************************************/
-void lm_boardinitialize(void)
+void tiva_boardinitialize(void)
{
/* Configure SPI chip selects if 1) SSI is not disabled, and 2) the weak function
* lm_ssiinitialize() has been brought into the link.
diff --git a/nuttx/configs/lm3s6965-ek/src/up_ethernet.c b/nuttx/configs/lm3s6965-ek/src/up_ethernet.c
index 81d6cda26..0d064e7d6 100644
--- a/nuttx/configs/lm3s6965-ek/src/up_ethernet.c
+++ b/nuttx/configs/lm3s6965-ek/src/up_ethernet.c
@@ -63,7 +63,7 @@
************************************************************************************/
/************************************************************************************
- * Name: lm_ethernetmac
+ * Name: tiva_ethernetmac
*
* Description:
* For the Ethernet Eval Kits, the MAC address will be stored in the non-volatile
@@ -73,7 +73,7 @@
************************************************************************************/
#ifdef CONFIG_LM_BOARDMAC
-void lm_ethernetmac(struct ether_addr *ethaddr)
+void tiva_ethernetmac(struct ether_addr *ethaddr)
{
uint32_t user0;
uint32_t user1;
diff --git a/nuttx/configs/lm3s6965-ek/src/up_leds.c b/nuttx/configs/lm3s6965-ek/src/up_leds.c
index e6ca445d6..216e95271 100644
--- a/nuttx/configs/lm3s6965-ek/src/up_leds.c
+++ b/nuttx/configs/lm3s6965-ek/src/up_leds.c
@@ -48,7 +48,7 @@
#include "chip.h"
#include "up_arch.h"
#include "up_internal.h"
-#include "lm_gpio.h"
+#include "tiva_gpio.h"
#include "lm3s6965ek_internal.h"
/****************************************************************************
@@ -70,7 +70,7 @@
/* Dump GPIO registers */
#ifdef CONFIG_DEBUG_LEDS
-# define led_dumpgpio(m) lm_dumpgpio(LED_GPIO, m)
+# define led_dumpgpio(m) tiva_dumpgpio(LED_GPIO, m)
#else
# define led_dumpgpio(m)
#endif
@@ -100,9 +100,9 @@ void board_led_initialize(void)
/* Configure Port E, Bit 1 as an output, initial value=OFF */
- led_dumpgpio("board_led_initialize before lm_configgpio()");
- lm_configgpio(LED_GPIO);
- led_dumpgpio("board_led_initialize after lm_configgpio()");
+ led_dumpgpio("board_led_initialize before tiva_configgpio()");
+ tiva_configgpio(LED_GPIO);
+ led_dumpgpio("board_led_initialize after tiva_configgpio()");
g_nest = 0;
}
@@ -126,9 +126,9 @@ void board_led_on(int led)
g_nest++;
case LED_IRQSENABLED:
case LED_STACKCREATED:
- led_dumpgpio("board_led_on: before lm_gpiowrite()");
- lm_gpiowrite(LED_GPIO, false);
- led_dumpgpio("board_led_on: after lm_gpiowrite()");
+ led_dumpgpio("board_led_on: before tiva_gpiowrite()");
+ tiva_gpiowrite(LED_GPIO, false);
+ led_dumpgpio("board_led_on: after tiva_gpiowrite()");
break;
}
}
@@ -154,9 +154,9 @@ void board_led_off(int led)
case LED_PANIC:
if (--g_nest <= 0)
{
- led_dumpgpio("board_led_off: before lm_gpiowrite()");
- lm_gpiowrite(LED_GPIO, true);
- led_dumpgpio("board_led_off: after lm_gpiowrite()");
+ led_dumpgpio("board_led_off: before tiva_gpiowrite()");
+ tiva_gpiowrite(LED_GPIO, true);
+ led_dumpgpio("board_led_off: after tiva_gpiowrite()");
}
break;
}
diff --git a/nuttx/configs/lm3s6965-ek/src/up_oled.c b/nuttx/configs/lm3s6965-ek/src/up_oled.c
index 5760a6974..6f95c599a 100644
--- a/nuttx/configs/lm3s6965-ek/src/up_oled.c
+++ b/nuttx/configs/lm3s6965-ek/src/up_oled.c
@@ -48,7 +48,7 @@
#include <nuttx/lcd/lcd.h>
#include <nuttx/lcd/p14201.h>
-#include "lm_gpio.h"
+#include "tiva_gpio.h"
#include "lm3s6965ek_internal.h"
/****************************************************************************
@@ -72,8 +72,8 @@
#ifdef CONFIG_LCD_RITDEBUG
# define ritdbg(format, arg...) vdbg(format, ##arg)
-# define oleddc_dumpgpio(m) lm_dumpgpio(OLEDDC_GPIO, m)
-# define oledcs_dumpgpio(m) lm_dumpgpio(OLEDCS_GPIO, m)
+# define oleddc_dumpgpio(m) tiva_dumpgpio(OLEDDC_GPIO, m)
+# define oledcs_dumpgpio(m) tiva_dumpgpio(OLEDCS_GPIO, m)
#else
# define ritdbg(x...)
# define oleddc_dumpgpio(m)
@@ -102,8 +102,8 @@ FAR struct lcd_dev_s *up_nxdrvinit(unsigned int devno)
oledcs_dumpgpio("up_nxdrvinit: After OLEDCS setup");
oleddc_dumpgpio("up_nxdrvinit: On entry");
- lm_configgpio(OLEDDC_GPIO); /* PC7: OLED display data/control select (D/Cn) */
- lm_configgpio(OLEDEN_GPIO); /* PC6: Enable +15V needed by OLED (EN+15V) */
+ tiva_configgpio(OLEDDC_GPIO); /* PC7: OLED display data/control select (D/Cn) */
+ tiva_configgpio(OLEDEN_GPIO); /* PC6: Enable +15V needed by OLED (EN+15V) */
oleddc_dumpgpio("up_nxdrvinit: After OLEDDC/EN setup");
@@ -137,7 +137,7 @@ FAR struct lcd_dev_s *up_nxdrvinit(unsigned int devno)
}
/******************************************************************************
- * Name: lm_spicmddata
+ * Name: tiva_spicmddata
*
* Description:
* Set or clear the SD1329 D/Cn bit to select data (true) or command
@@ -159,14 +159,15 @@ FAR struct lcd_dev_s *up_nxdrvinit(unsigned int devno)
*
******************************************************************************/
-int lm_spicmddata(FAR struct spi_dev_s *dev, enum spi_dev_e devid, bool cmd)
+int tiva_spicmddata(FAR struct spi_dev_s *dev, enum spi_dev_e devid, bool cmd)
{
if (devid == SPIDEV_DISPLAY)
{
/* Set GPIO to 1 for data, 0 for command */
- lm_gpiowrite(OLEDDC_GPIO, !cmd);
+ tiva_gpiowrite(OLEDDC_GPIO, !cmd);
return OK;
}
+
return -ENODEV;
}
diff --git a/nuttx/configs/lm3s6965-ek/src/up_ssi.c b/nuttx/configs/lm3s6965-ek/src/up_ssi.c
index 934e01afa..869521d8f 100644
--- a/nuttx/configs/lm3s6965-ek/src/up_ssi.c
+++ b/nuttx/configs/lm3s6965-ek/src/up_ssi.c
@@ -49,7 +49,7 @@
#include "up_arch.h"
#include "chip.h"
-#include "lm_gpio.h"
+#include "tiva_gpio.h"
#include "lm3s6965ek_internal.h"
/* The LM3S6965 Eval Kit microSD CS is on SSI0 */
@@ -81,7 +81,7 @@
/* Dump GPIO registers */
#ifdef SSI_VERBOSE
-# define ssi_dumpgpio(m) lm_dumpgpio(SDCCS_GPIO, m)
+# define ssi_dumpgpio(m) tiva_dumpgpio(SDCCS_GPIO, m)
#else
# define ssi_dumpgpio(m)
#endif
@@ -95,7 +95,7 @@
************************************************************************************/
/************************************************************************************
- * Name: lm_ssiinitialize
+ * Name: tiva_ssiinitialize
*
* Description:
* Called to configure SPI chip select GPIO pins for the LM3S6965 Eval Kit.
@@ -107,21 +107,21 @@ void weak_function lm_ssiinitialize(void)
/* Configure the SPI-based microSD CS GPIO */
ssi_dumpgpio("lm_ssiinitialize() Entry)");
- lm_configgpio(SDCCS_GPIO);
+ tiva_configgpio(SDCCS_GPIO);
#ifdef CONFIG_NX_LCDDRIVER
- lm_configgpio(OLEDCS_GPIO);
+ tiva_configgpio(OLEDCS_GPIO);
#endif
ssi_dumpgpio("lm_ssiinitialize() Exit");
}
/****************************************************************************
* The external functions, lm_spiselect and lm_spistatus must be provided
* by board-specific logic. The are implementations of the select and status
* methods SPI interface defined by struct spi_ops_s (see include/nuttx/spi/spi.h).
* All othermethods (including up_spiinitialize()) are provided by common
* logic. To use this common SPI logic on your board:
*
* 1. Provide lm_spiselect() and lm_spistatus() functions in your
* board-specific logic. This function will perform chip selection and
* status operations using GPIOs in the way your board is configured.
* 2. Add a call to up_spiinitialize() in your low level initialization
@@ -133,29 +133,29 @@ void weak_function lm_ssiinitialize(void)
*
****************************************************************************/
-void lm_spiselect(FAR struct spi_dev_s *dev, enum spi_dev_e devid, bool selected)
+void tiva_spiselect(FAR struct spi_dev_s *dev, enum spi_dev_e devid, bool selected)
{
ssidbg("devid: %d CS: %s\n", (int)devid, selected ? "assert" : "de-assert");
- ssi_dumpgpio("lm_spiselect() Entry");
+ ssi_dumpgpio("tiva_spiselect() Entry");
if (devid == SPIDEV_MMCSD)
{
/* Assert the CS pin to the card */
- lm_gpiowrite(SDCCS_GPIO, !selected);
+ tiva_gpiowrite(SDCCS_GPIO, !selected);
}
#ifdef CONFIG_NX_LCDDRIVER
else if (devid == SPIDEV_DISPLAY)
{
/* Assert the CS pin to the display */
- lm_gpiowrite(OLEDCS_GPIO, !selected);
+ tiva_gpiowrite(OLEDCS_GPIO, !selected);
}
#endif
- ssi_dumpgpio("lm_spiselect() Exit");
+ ssi_dumpgpio("tiva_spiselect() Exit");
}
-uint8_t lm_spistatus(FAR struct spi_dev_s *dev, enum spi_dev_e devid)
+uint8_t tiva_spistatus(FAR struct spi_dev_s *dev, enum spi_dev_e devid)
{
ssidbg("Returning SPI_STATUS_PRESENT\n");
return SPI_STATUS_PRESENT;
@@ -107,21 +107,21 @@ void weak_function lm_ssiinitialize(void)
}
/****************************************************************************
- * The external functions, lm_spiselect and lm_spistatus must be provided
+ * The external functions, tiva_spiselect and tiva_spistatus must be provided
* by board-specific logic. The are implementations of the select and status
* methods SPI interface defined by struct spi_ops_s (see include/nuttx/spi/spi.h).
@@ -107,21 +107,21 @@ void weak_function lm_ssiinitialize(void)
* logic. To use this common SPI logic on your board:
*
- * 1. Provide lm_spiselect() and lm_spistatus() functions in your
+ * 1. Provide tiva_spiselect() and tiva_spistatus() functions in your
* board-specific logic. This function will perform chip selection and
* status operations using GPIOs in the way your board is configured.